<?php

declare(strict_types=1);

namespace Drupal\joinup_solution;

use Drupal\node\NodeInterface;

/**
 * Provides an interface the 'joinup_solution.title_duplicate_helper' service.
 */
interface SolutionTitleDuplicateHelperInterface {

  /**
   * Checks if the given solution's title is already in use.
   *
   * @param \Drupal\node\NodeInterface $solution
   *   The solution to be checked.
   *
   * @return bool
   *   If other solutions with the same doesn't name exist.
   *
   * @throws \Exception
   *   The passed entity is not a solution.
   */
  public function titleIsUnique(NodeInterface $solution): bool;

  /**
   * Checks if a solution's title is already in use within the same affiliation.
   *
   * @param \Drupal\node\NodeInterface $solution
   *   The solution to be checked.
   *
   * @return bool|null
   *   FALSE, if other solutions with the same name exist within the same
   *   affiliation, TRUE otherwise. If the solution's title has duplicates but
   *   its affiliation cannot be determined, returns NULL.
   *
   * @throws \Exception
   *   The passed entity is not a solution.
   */
  public function titleIsUniqueWithinAffiliation(NodeInterface $solution): ?bool;

}
